@@ -527,6 +527,7 @@ def cooldown(rate, per, type=BucketType.default):
         return func
     return decorator
 
+
 #-----------------------------------+
 #      Slash-commands client        |
 #-----------------------------------+
@@ -570,6 +571,9 @@ class SlashClient:
         self.client.remove_cog = rem_cog_2
         # Link the slash ext to client
         self.client.slash = self
+        # Inject cogs that are already loaded
+        for cog in self.client.cogs.values():
+            self._inject_cogs(cog)
 
     @property
     def commands(self):
@@ -1130,7 +1134,7 @@ class SlashClient:
         '''
         inter = Interaction(self.client, payload)
         # Activate event
-        self.client.loop.create_task(self._activate_event('slash_command', inter))
+        await self._activate_event('slash_command', inter)
         # Invoke command
         SCR = self.commands.get(inter.data.name)
         if SCR is not None:
